@@ -262,9 +262,9 @@ compute_frequency_analysis <- function(data,
   if(!use_max){ freqplot <- freqplot + ggplot2::theme(legend.justification = c(1, 1), legend.position = c(.98, .98))}
   if(use_max){ freqplot <- freqplot + ggplot2::theme(legend.justification = c(1,0), legend.position = c(.98, 0.02))}
   if(!use_log){ freqplot <- freqplot + ggplot2::scale_y_log10(breaks = scales::pretty_breaks(n = 10),
-                                                              labels = scales::label_number(scale_cut = scales::cut_short_scale()))}
+                                                              labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))}
   if(use_log){ freqplot <- freqplot + ggplot2::scale_y_continuous(breaks = scales::pretty_breaks(n = 10),
-                                                                  labels = scales::label_number(scale_cut = scales::cut_short_scale()))}
+                                                                  labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))}
   # if(use_log &  use_max ){freqplot <- freqplot + ggplot2::ylab(expression(lnDischarge~(m^3/s)))}  # adjust the Y axis label
   # if(use_log & !use_max){freqplot <- freqplot + ggplot2::ylab(expression(lnDischarge~(m^3/s)))}
   # if(!use_log &  use_max ){freqplot <- freqplot + ggplot2::ylab(expression(Discharge~(m^3/s)))}
