@@ -298,9 +298,9 @@ plot_annual_extremes_year <- function(data,
         {if(plot_max) ggplot2::geom_point(ggplot2::aes(x= Date, y = Max_Value, fill = high_lab), size = 3.5, na.rm = TRUE, shape = 21) }+
         {if(!log_discharge) ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, 0.05)),
                                                         breaks = scales::pretty_breaks(n = 8),
-                                                        labels = scales::label_number(scale_cut = scales::cut_short_scale()))}+
+                                                        labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))}+
         {if(log_discharge) ggplot2::scale_y_log10(breaks = scales::log_breaks(n = 8, base = 10),
-                                                  labels = scales::label_number(scale_cut = scales::cut_short_scale()))} +
+                                                  labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))} +
         {if(log_discharge & log_ticks) ggplot2::annotation_logticks(base= 10, "left", colour = "grey25", size = 0.3,
                                                                     short = ggplot2::unit(.07, "cm"), mid = ggplot2::unit(.15, "cm"),
                                                                     long = ggplot2::unit(.2, "cm"))} +
