@@ -168,10 +168,10 @@ plot_monthly_stats <- function(data,
         {if(length(unique(monthly_data$Year)) < 6) ggplot2::scale_x_continuous(breaks = unique(monthly_data$Year))}+
         {if(!log_discharge) ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, 0.05)),
                                                         breaks = scales::pretty_breaks(n = 8),
-                                                        labels = scales::label_number(scale_cut = scales::cut_short_scale()))} +
+                                                        labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))} +
         {if(log_discharge) ggplot2::scale_y_log10(expand =ggplot2::expansion(mult = c(0, 0.05)), 
                                                   breaks = scales::log_breaks(n = 8, base = 10),
-                                                  labels = scales::label_number(scale_cut = scales::cut_short_scale()))} +
+                                                  labels = scales::label_number(scale_cut = append(scales::cut_short_scale(),1,1)))} +
         {if(log_discharge & log_ticks) ggplot2::annotation_logticks(
           base = 10, "left", colour = "grey25", size = 0.3,
           short = ggplot2::unit(.07, "cm"), mid = ggplot2::unit(.15, "cm"),
